<?php // phpcs:ignore Drupal.Commenting.FileComment.Missing

declare(strict_types=1);

/**
 * @file
 * Post update functions for Component library module.
 */

use Drupal\Core\Database\Database;

/**
 * Rename entity prefix for pattens and variations.
 */
function component_library_post_update_entity_prefix(&$sandbox = []): void {
  $config_to_update = [
    'component_library.component_library_pattern' => 'component_library.pattern',
    'component_library.component_library_variant' => 'component_library.variant',
  ];
  $connection = Database::getConnection();
  foreach ($config_to_update as $old_prefix => $new_prefix) {
    $query = $connection->select('config', 'c')
      ->fields('c', ['name', 'data'])
      ->condition('collection', '')
      ->condition('name', "$old_prefix.%", 'LIKE');
    foreach ($query->execute()->fetchAllKeyed() as $name => $data) {
      $data = unserialize($data, ['allowed_classes' => FALSE]);
      foreach ($data['dependencies'] as $type => $dependencies) {
        foreach ($dependencies as $key => $dependency) {
          $data['dependencies'][$type][$key] = str_replace('component_library.component_library_pattern', 'component_library.pattern', $dependency);
        }
      }
      $connection->update('config')
        ->condition('collection', '')
        ->condition('name', $name)
        ->fields([
          'name' => \str_replace($old_prefix, $new_prefix, $name),
          'data' => serialize($data),
        ])->execute();
    }
  }
}
