<?php

declare(strict_types=1);

namespace Drupal\component_library;

use Drupal\component_library\Entity\ComponentLibraryAsset;

final class Asset {

  public function processAllAssetPaths(callable $callback, $url = TRUE): void {
    $assets = ComponentLibraryAsset::loadMultiple();
    foreach ($assets as $asset) {
      $paths = $asset->get('paths');
      foreach ($paths as $path_info) {
        $path_info['id'] = $asset->id();
        if ($url) {
          $path_info['path'] = $this->fileUrlGenerator($path_info['path']);
        }
        \call_user_func($callback, $path_info);
      }
    }
  }

  private function fileUrlGenerator($file_uri): string {
    if (\version_compare(\Drupal::VERSION, '9.3', '>=')) {
      // phpcs:ignore DrupalPractice.Objects.GlobalDrupal.GlobalDrupal
      return \Drupal::service('file_url_generator')->generateString($file_uri);
      // phpcs:enable
    }
    else {
      return \file_create_url($file_uri);
    }
  }

}
